@@ -22,6 +22,9 @@ package File::StripNondeterminism::handlers::png;
 use strict;
 use warnings;
 
+use Archive::Zip ();
+use File::Temp;
+use File::StripNondeterminism;
 use File::StripNondeterminism::Common qw(copy_data);
 use File::Basename qw/dirname/;
 use POSIX qw/strftime/;
